# cs207-FinalProject

**Group number**: 28

**Team Members**:

Josh Bodner

Theo Guenais

Daiki Ina

Junzhi Gong

### Download and use autodiff
* Activate virtual environment
* Install the package
    ```bash
    pip install "pip install autodiff-ADdictedtoCS"

* (Optional) Run tests with pytest 
    ```bash 
    $pytest 

* Enjoy the features and natural approach of ```autodiff``` for automatic differentiation. Refer to the documentation for further information, 
or the demo.ipynb notebook for basic use case.
